Learn R Programming

LaplacesDemon (version 16.1.6)

print.demonoid: Print an object of class demonoid to the screen.

Description

This may be used to print the contents of an object of class demonoid to the screen.

Usage

# S3 method for demonoid
print(x, ...)

Arguments

x

An object of class demonoid is required.

...

Additional arguments are unused.

Author

Statisticat, LLC. software@bayesian-inference.com

Details

If the user has an object of class demonoid.hpc, then the print function may still be used by specifying the chain as a component in a list, such as printing the second chain with print(Fit[[2]]) when the demonoid.hpc object is named Fit, for example.

See Also

Consort, LaplacesDemon, and LaplacesDemon.hpc.

Examples

Run this code
### See the LaplacesDemon function for an example.

Run the code above in your browser using DataLab