Learn R Programming

LaplacesDemon (version 16.1.6)

print.heidelberger: Print an object of class heidelberger to the screen.

Description

This may be used to print the contents of an object of class heidelberger to the screen.

Usage

# S3 method for heidelberger
print(x, digits=3, ...)

Arguments

x

An object of class heidelberger is required.

digits

This is the number of digits to print.

...

Additional arguments are unused.

Author

Statisticat, LLC. software@bayesian-inference.com

See Also

Heidelberger.Diagnostic.

Examples

Run this code
### See the Heidelberger.Diagnostic function for an example.

Run the code above in your browser using DataLab