Learn R Programming

LaplacesDemon (version 16.1.6)

print.iterquad: Print an object of class iterquad to the screen.

Description

This may be used to print the contents of an object of class iterquad to the screen.

Usage

# S3 method for iterquad
print(x, ...)

Arguments

x

An object of class iterquad is required.

...

Additional arguments are unused.

Author

Statisticat, LLC. software@bayesian-inference.com

See Also

IterativeQuadrature

Examples

Run this code
### See the IterativeQuadrature function for an example.

Run the code above in your browser using DataLab