Learn R Programming

LaplacesDemon (version 16.1.6)

print.laplace: Print an object of class laplace to the screen.

Description

This may be used to print the contents of an object of class laplace to the screen.

Usage

# S3 method for laplace
print(x, ...)

Arguments

x

An object of class laplace is required.

...

Additional arguments are unused.

Author

Statisticat, LLC. software@bayesian-inference.com

See Also

LaplaceApproximation

Examples

Run this code
### See the LaplaceApproximation function for an example.

Run the code above in your browser using DataLab