powered by
pmc
This may be used to print the contents of an object of class pmc to the screen.
# S3 method for pmc print(x, ...)
An object of class pmc is required.
Additional arguments are unused.
Statisticat, LLC. software@bayesian-inference.com
PMC.
PMC
### See the PMC function for an example.
Run the code above in your browser using DataLab