Learn R Programming

LaplacesDemon (version 16.1.6)

summary.miss: MISS Summary

Description

This function summarizes posterior predictive distributions from an object of class miss.

Usage

# S3 method for miss
summary(object, ...)

Value

This function returns a \(M \times 7\) matrix, in which each row is the posterior predictive distribution of one of \(M\) missing values. Columns are Mean, SD, MCSE, ESS, LB, Median, and UB.

Arguments

object

An object of class miss is required.

...

Additional arguments are unused.

Author

Statisticat, LLC. software@bayesian-inference.com

Details

This function summarizes the posterior predictive distributions from an object of class miss.

See Also

MISS.

Examples

Run this code
### See the MISS function for an example.

Run the code above in your browser using DataLab