If the user has an object of class demonoid.hpc, then the
print function may still be used by specifying the chain as a
component in a list, such as printing the second chain with
print(Fit[[2]]) when the demonoid.hpc object is named
Fit, for example.