powered by
heidelberger
This may be used to print the contents of an object of class heidelberger to the screen.
# S3 method for heidelberger print(x, digits=3, ...)
An object of class heidelberger is required.
This is the number of digits to print.
Additional arguments are unused.
Statisticat, LLC. software@bayesian-inference.com
Heidelberger.Diagnostic.
Heidelberger.Diagnostic
### See the Heidelberger.Diagnostic function for an example.
Run the code above in your browser using DataLab