powered by
iterquad
This may be used to print the contents of an object of class iterquad to the screen.
# S3 method for iterquad print(x, ...)
An object of class iterquad is required.
Additional arguments are unused.
Statisticat, LLC. software@bayesian-inference.com
IterativeQuadrature
### See the IterativeQuadrature function for an example.
Run the code above in your browser using DataLab