powered by
laplace
This may be used to print the contents of an object of class laplace to the screen.
# S3 method for laplace print(x, ...)
An object of class laplace is required.
Additional arguments are unused.
Statisticat, LLC. software@bayesian-inference.com
LaplaceApproximation
### See the LaplaceApproximation function for an example.
Run the code above in your browser using DataLab