powered by
raftery
This may be used to print the contents of an object of class raftery to the screen.
# S3 method for raftery print(x, digits=3, ...)
An object of class raftery is required.
This is the number of digits to print.
Additional arguments are unused.
Statisticat, LLC. software@bayesian-inference.com
Raftery.Diagnostic.
Raftery.Diagnostic
### See the Raftery.Diagnostic function for an example.
Run the code above in your browser using DataLab